import { Component, OnInit } from '@angular/core';
import { Router, NavigationEnd } from '@angular/router';
import { ConfigService } from '../../../services/config.service';
import { AdminRoutes } from '../../admin-routing.module';
import { filter } from 'rxjs/operators';

@Component({
  selector: 'app-admin-nav-bar',
  templateUrl: './nav-bar.component.html',
  styleUrls: ['./nav-bar.component.scss'],
})
export class NavBarComponent implements OnInit {
  public routes = AdminRoutes;
  private ghostLink: string;
  public currentRoute: string;

  public buttons = [
    { label: 'Revendication structure', route: this.routes.pendingStructures.link },
    { label: 'Liste structures', route: this.routes.structuresList.link },
    { label: 'Structures supprimées', route: this.routes.deletedStructures.link },
    { label: 'Gestion des utilisateurs', route: this.routes.manageUsers.link },
    { label: 'Fonctions', route: this.routes.jobsList.link },
    { label: 'Employeurs', route: this.routes.employersList.link },
    { label: 'CNFS Espace Coop', route: this.routes.espaceCoopCNFS.link },
  ];

  constructor(
    public router: Router,
    private configService: ConfigService,
  ) {}

  ngOnInit(): void {
    // Fetch configuration and set ghost link
    this.configService.getConfig().then((config) => {
      this.ghostLink = config.ghostAdminUrl;
    });

    this.router.events.pipe(filter((event) => event instanceof NavigationEnd)).subscribe((event: NavigationEnd) => {
      this.currentRoute = event.urlAfterRedirects || event.url;
    });

    this.currentRoute = this.router.url.substring(1);
  }

  public openGhost(): void {
    window.open(this.ghostLink);
  }

  public navigateTo(route: string): void {
    this.router.navigateByUrl(route);
  }

  public isActive(route: string): string {
    return this.currentRoute === route ? 'active' : '';
  }
}
